Development
-----------
Download the official development repository using Git_::

    git clone https://github.com/nicoretti/prysk.git

Visit GitHub_ if you'd like to fork the project, watch for new changes, or
report issues.

.. _Git: http://git-scm.com/
.. _GitHub: https://github.com/nicoretti/prysk
